@@ -23,8 +23,11 @@
 
 package ch.kuramo.javie.api;
 
-import ch.kuramo.javie.api.Vec2d;
-
+/**
+ * アニメーション可能な{@link Vec2d}型のプロパティを表すインターフェースです。
+ * このインターフェースは <i>不透明型</i> であり、メソッド等はありません。
+ * 使用方法は {@link IAnimatableDouble} をご覧ください。
+ */
 public interface IAnimatableVec2d extends IAnimatableValue<Vec2d> {
 
 }
