@@ -23,8 +23,10 @@
 
 package ch.kuramo.javie.api.services;
 
+import ch.kuramo.javie.api.GeometryInputType;
+import ch.kuramo.javie.api.GeometryOutputType;
 import ch.kuramo.javie.api.IShaderProgram;
-import ch.kuramo.javie.api.IShaderSourceFactory;
+import ch.kuramo.javie.api.ShaderType;
 
 /**
  * <code>IShaderRegistry</code> は {@link IShaderProgram} オブジェクトを管理するサービスです。
@@ -54,15 +56,31 @@ public interface IShaderRegistry {
 	IShaderProgram getProgram(Class<?> clazz, String name);
 
 	/**
-	 * @deprecated このメソッドは、将来、変更または廃止される可能性があります。
+	 * @since 0.5.1
 	 */
-	@Deprecated
-	IShaderProgram getProgram(IShaderSourceFactory sourceFactory);
+	IShaderProgram registerProgram(String name, ShaderType type, String[] attach, String[] source);
 
 	/**
-	 * @deprecated このメソッドは、将来、変更または廃止される可能性があります。
+	 * @since 0.5.1
 	 */
-	@Deprecated
-	void addShader(IShaderSourceFactory sourceFactory);
+	IShaderProgram registerProgramWithGeometryShader(
+			String name, String[] attach, String[] source,
+			GeometryInputType inputType, GeometryOutputType outputType, int verticesOut);
+
+	/**
+	 * @since 0.5.1
+	 */
+	boolean isShaderRegistered(String name);
+
+	/**
+	 * @since 0.5.1
+	 */
+	void registerShader(String name, ShaderType type, String[] source);
+
+	/**
+	 * @since 0.5.1
+	 */
+	void registerGeometryShader(String name, String[] source,
+			GeometryInputType inputType, GeometryOutputType outputType, int verticesOut);
 
 }
