@@ -44,6 +44,7 @@ import ch.kuramo.javie.core.Item;
 import ch.kuramo.javie.core.MediaInputPlaceholder;
 import ch.kuramo.javie.core.MediaItem;
 import ch.kuramo.javie.core.SolidColorItem;
+import ch.kuramo.javie.core.SuperSampling;
 
 public class ImageUtil {
 
@@ -67,7 +68,6 @@ public class ImageUtil {
 
 		ImageRegistry registry = getRegistry();
 
-		color = color.clamp();
 		final int red = (int)(color.r*255);
 		final int green = (int)(color.g*255);
 		final int blue = (int)(color.b*255);
@@ -153,6 +153,10 @@ public class ImageUtil {
 		return PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_OBJ_ELEMENT);
 	}
 
+	public static Image getLightIcon() {
+		return getRegistry().get(Activator.IMG_LIGHT);
+	}
+
 	public static Image getCameraIcon() {
 		return getRegistry().get(Activator.IMG_CAMERA);
 	}
@@ -208,6 +212,17 @@ public class ImageUtil {
 		return getRegistry().getDescriptor(Activator.IMG_COMP_SETTINGS);
 	}
 
+	public static ImageDescriptor getCompositionSuperSamplingIcon(SuperSampling superSampling) {
+		String key;
+		switch (superSampling) {
+			case SS_2X2: key = Activator.IMG_COMP_SS_2X2; break;
+			case SS_3X3: key = Activator.IMG_COMP_SS_3X3; break;
+			case SS_4X4: key = Activator.IMG_COMP_SS_4X4; break;
+			default: key = Activator.IMG_COMP_SS_NONE; break;
+		}
+		return getRegistry().getDescriptor(key);
+	}
+
 	public static ImageDescriptor getCompositionMotionBlurIcon() {
 		return getRegistry().getDescriptor(Activator.IMG_COMP_MBLUR);
 	}
