@@ -30,7 +30,7 @@ import net.arnx.jsonic.JSONHint;
 import org.mozilla.javascript.Context;
 
 import ch.kuramo.javie.api.IAnimatableEnum;
-import ch.kuramo.javie.core.exprelems.StringProperty;
+import ch.kuramo.javie.core.expression.StringProperty;
 
 public abstract class AbstractAnimatableEnum<E extends Enum<E>>
 		extends AbstractAnimatableValue<E> implements AnimatableEnum<E>, IAnimatableEnum<E> {
