@@ -27,11 +27,10 @@ import ch.kuramo.javie.api.AudioMode;
 import ch.kuramo.javie.api.IArray;
 import ch.kuramo.javie.api.IAudioBuffer;
 import ch.kuramo.javie.api.services.IArrayPools;
-import ch.kuramo.javie.core.AudioBuffer;
 
 import com.google.inject.Inject;
 
-public class AudioBufferImpl implements AudioBuffer, IAudioBuffer {
+public class AudioBufferImpl implements IAudioBuffer {
 
 	private final AudioMode _audioMode;
 
@@ -39,8 +38,6 @@ public class AudioBufferImpl implements AudioBuffer, IAudioBuffer {
 
 	private final int _dataLength;
 
-	private final int _dataLengthInBytes;
-
 	private IArray<?> _data;
 
 	@Inject
@@ -51,7 +48,6 @@ public class AudioBufferImpl implements AudioBuffer, IAudioBuffer {
 		_audioMode = audioMode;
 		_frameCount = frameCount;
 		_dataLength = frameCount * audioMode.channels;
-		_dataLengthInBytes = _dataLength * audioMode.sampleSize;
 	}
 
 	@Override
@@ -79,10 +75,6 @@ public class AudioBufferImpl implements AudioBuffer, IAudioBuffer {
 		return _dataLength;
 	}
 
-	public int getDataLengthInBytes() {
-		return _dataLengthInBytes;
-	}
-
 	public Object getData() {
 		if (_data == null) {
 			switch (_audioMode.dataType) {
