@@ -23,7 +23,6 @@
 
 package ch.kuramo.javie.core.internal.services;
 
-import java.lang.reflect.Array;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
@@ -95,7 +94,7 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		_exprInterface = exprInterface;
 		_bundle = getBundle();
 		_category = interiorClass.getAnnotation(ch.kuramo.javie.api.annotations.Effect.class).category().trim();
-		_label = getString("label");
+		_label = getString("label", defaultLabel(interiorClass.getSimpleName()));
 		_propertyDescriptorMap = Collections.unmodifiableMap(createPropertyDescriptors());
 		_propertyDescriptorList = Collections.unmodifiableList(Util.newList(_propertyDescriptorMap.values()));
 	}
@@ -115,11 +114,6 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		}
 	}
 
-	private String getString(String key) {
-		String str = getString(key, null);
-		return (str != null) ? str : ('!' + key + '!');
-	}
-
 	private String getString(String key, String defaultStr) {
 		String str = null;
 		if (_bundle != null) {
@@ -132,6 +126,24 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		return (str != null) ? str : defaultStr;
 	}
 
+	private String defaultLabel(String name) {
+		StringBuilder sb = new StringBuilder();
+
+		char c = name.charAt(0);
+		sb.append(Character.toUpperCase(c));
+		boolean prevLower = false;
+
+		for (int i = 1, n = name.length(); i < n; ++i) {
+			c = name.charAt(i);
+			boolean lower = Character.isLowerCase(c);
+			if (!lower && prevLower) sb.append(' ');
+			sb.append(c);
+			prevLower = lower;
+		}
+
+		return sb.toString();
+	}
+
 	private Map<String, PropertyDescriptor> createPropertyDescriptors() {
 		Map<String, PropertyDescriptor> map = Util.newLinkedHashMap();
 
@@ -242,7 +254,7 @@ class EffectDescriptorImpl implements EffectDescriptor {
 			super();
 			this.type = type;
 			this.name = name;
-			this.label = EffectDescriptorImpl.this.getString(name + ".label");
+			this.label = EffectDescriptorImpl.this.getString(name + ".label", defaultLabel(name));
 			try {
 				String upperCamelCase = Character.toUpperCase(name.charAt(0)) + name.substring(1);
 				getter = _exteriorClass.getDeclaredMethod("get" + upperCamelCase);
@@ -690,17 +702,7 @@ class EffectDescriptorImpl implements EffectDescriptor {
 			return Enum.valueOf(enumType, s.trim());
 		} catch (IllegalArgumentException e) {
 			// TODO ログに警告を出す
-		}
-		try {
-			@SuppressWarnings("unchecked")
-			E first = (E) Array.get(enumType.getMethod("values").invoke(null), 0);
-			return first;
-		} catch (IllegalAccessException e) {
-			throw new JavieRuntimeException(e);
-		} catch (InvocationTargetException e) {
-			throw new JavieRuntimeException(e);
-		} catch (NoSuchMethodException e) {
-			throw new JavieRuntimeException(e);
+			return enumType.getEnumConstants()[0];
 		}
 	}
 
