@@ -66,8 +66,19 @@ public class MediaSourceFactoryImpl implements MediaSourceFactory {
 
 		if ((clazz = classForName("ch.kuramo.javie.core.internal.MacOSXQTCoreVideoSource")) != null) {
 			_sourceClasses.add(JavaImageSource.class);
-			_sourceClasses.add(JavaSoundSource.class);	// サンプルレートの変換が行われるときはQTの方だとノイズが乗るので、JavaSoundSourceを前に入れておく。
-			_sourceClasses.add(clazz);					// (QT Playerでサンプルレートを変換して書き出しても問題ないようなので、Javieの実装が何かまずいと思われる)
+			_sourceClasses.add(JavaSoundSource.class);	// サンプルレートの変換が行われるときはQTの方だとノイズが乗るので、
+														// JavaSoundSourceをMacOSXQTCoreVideoSourceより前に入れておく。
+														// (QT Playerでサンプルレートを変換して書き出しても問題ないようなので、Javieの実装が何かまずいと思われる)
+
+			// Quartz Composer のアプリはデベロッパーツールを入れる必要があるが
+			// QuartzComposer.framework はデベロッパーツール無しでもインストールされているのだろうか？
+			// インストールされていない場合は QCCompositionSource がロード出来ないので、チェックする必要がある。
+			Class<MediaSource> qccsClass = classForName("ch.kuramo.javie.core.internal.QCCompositionSource");
+			if (qccsClass != null) {
+				_sourceClasses.add(qccsClass);
+			}
+
+			_sourceClasses.add(clazz);
 
 		} else if ((clazz = classForName("ch.kuramo.javie.core.internal.WindowsDirectShowSource")) != null) {
 			_sourceClasses.add(JavaImageSource.class);
