@@ -50,7 +50,7 @@ public class Tritone {
 
 	@ShaderSource
 	public static final String[] TRITONE = {
-		"uniform sampler2DRect texture;",
+		"uniform sampler2D texture;",
 		"uniform vec3 highlight;",
 		"uniform vec3 midtone;",
 		"uniform vec3 shadow;",
@@ -60,7 +60,7 @@ public class Tritone {
 		"",
 		"void main(void)",
 		"{",
-		"	vec4 src = texture2DRect(texture, gl_TexCoord[0].st);",
+		"	vec4 src = texture2D(texture, gl_TexCoord[0].st);",
 		"	float y = (src.a != 0.0) ? dot(src.rgb/src.a, yvec) : 0.0;",
 		"	vec3 rgb;",
 		"	if (y > 0.5) {",
@@ -115,9 +115,9 @@ public class Tritone {
 			return input;
 		}
 
-		Color highlight = context.value(this.highlight).clamp();
-		Color midtone = context.value(this.midtone).clamp();
-		Color shadow = context.value(this.shadow).clamp();
+		Color highlight = context.value(this.highlight);
+		Color midtone = context.value(this.midtone);
+		Color shadow = context.value(this.shadow);
 
 		try {
 			Set<GLUniformData> uniforms = new HashSet<GLUniformData>();
