@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -42,6 +42,7 @@ import ch.kuramo.javie.api.annotations.Property;
 import ch.kuramo.javie.api.annotations.Effect.Categories;
 import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.api.services.IBlendSupport;
+import ch.kuramo.javie.api.services.ITexture1DSupport;
 import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.api.services.IVideoRenderSupport;
 
@@ -80,9 +81,9 @@ public class LinearGradient extends GradientBase {
 	@Inject
 	public LinearGradient(
 			IVideoEffectContext context, IBlendSupport blendSupport,
-			IArrayPools arrayPools, IVideoRenderSupport support) {
+			ITexture1DSupport tex1DSupport, IArrayPools arrayPools, IVideoRenderSupport support) {
 
-		super(context, blendSupport, arrayPools);
+		super(context, blendSupport, tex1DSupport, arrayPools);
 		this.support = support;
 	}
 
